CREATE DATABASE IF NOT EXISTS ddb;

USE ddb;


CREATE TABLE `ddb`.`Customer` (
  `CustomerID` INTEGER UNSIGNED AUTO_INCREMENT,
  `Company` VARCHAR(200),
  `Country` VARCHAR(100),
  `State` VARCHAR(100),
  `ZIPCode` VARCHAR(100),
  `ContactAddress` VARCHAR(200),
  `ContactPhone` VARCHAR(100),
  `ContactFax` VARCHAR(100),
  `ContactPerson` VARCHAR(200),
  `ContactEmail` VARCHAR(100),
  `UseContactEmailForInfo` BIt DEFAULT 1,
  `Comment` VARCHAR(500),
  PRIMARY KEY(`CustomerID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`AccessLevel` (
  `LevelID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `LevelName` VARCHAR(50),
  `LevelDescription` VARCHAR(500),
  PRIMARY KEY(`LevelID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`Users` (
  `UserID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `CustomerID` INTEGER UNSIGNED NOT NULL,
  `UserName` VARCHAR(50) NOT NULL,
  `UserPassword` VARCHAR(512) NOT NULL,
  `RoleID` INTEGER UNSIGNED,
  `Name` VARCHAR(200),
  `Comment` VARCHAR(100),
  PRIMARY KEY(`UserID`),
  CONSTRAINT `FK_Users_Customers` FOREIGN KEY `FK_Users_Customers` (`CustomerID`)
    REFERENCES `customer` (`CustomerID`),
  CONSTRAINT `FK_Users_AccessLevel` FOREIGN KEY `FK_Users_AccessLevel` (`RoleID`)
    REFERENCES `accesslevel` (`LevelID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`Channels` (
  `ChannelID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `ChannelName` VARCHAR(50),
  `Channeldescription` VARCHAR(500),
  PRIMARY KEY(`ChannelID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`GPSDevices` (
  `DeviceDBID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `UserID` INTEGER UNSIGNED NOT NULL,
  `DeviceID` VARCHAR(8) NOT NULL,
  `ChannelID` INTEGER UNSIGNED DEFAULT 0,
  `GSMNumber` VARCHAR(50) NOT NULL,
  `ReportPeriod` INTEGER UNSIGNED NOT NULL,
  `GSMCardPinCode` VARCHAR(8) NOT NULL,
  `DeviceOnline` BIt DEFAULT 0,
  `VehicleModel` VARCHAR(100),
  `VehicleName` VARCHAR(100),
  `VehicleRegNumber` VARCHAR(100),
  `VehicleDriver` VARCHAR(100),
  `VehicleComment` VARCHAR(1000),
  PRIMARY KEY(`DeviceDBID`),
  CONSTRAINT `FK_GPSDevices_Users` FOREIGN KEY `FK_GPSDevices_Users` (`UserID`)
    REFERENCES `users` (`UserID`),
  CONSTRAINT `FK_GPSDevices_Channels` FOREIGN KEY `FK_GPSDevices_Channels` (`ChannelID`)
    REFERENCES `channels` (`ChannelID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`APN` (
  `ApnID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `DeviceDBID` INTEGER UNSIGNED NOT NULL,
  `ApnIP` VARCHAR(50) NOT NULL,
  `ApnPort` BIGINT UNSIGNED NOT NULL,
  PRIMARY KEY(`ApnID`),
  CONSTRAINT `FK_APN_GPSDevices` FOREIGN KEY `FK_APN_GPSDevices` (`DeviceDBID`)
    REFERENCES `gpsdevices` (`DeviceDBID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`GSMNumbers` (
  `GSMNumbersID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `DeviceDBID` INTEGER UNSIGNED NOT NULL,
  `GSMNumber` VARCHAR(100),
  `Enabled` BIt DEFAULT 0,
  PRIMARY KEY(`GSMNumbersID`),
  CONSTRAINT `FK_GSMNumbers_GPSDevices` FOREIGN KEY `FK_GSMNumbers_GPSDevices` (`DeviceDBID`)
    REFERENCES `gpsdevices` (`DeviceDBID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`PinNames` (
  `PinNameDBID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `DeviceDBID` INTEGER UNSIGNED NOT NULL,
  `PinID` INTEGER UNSIGNED NOT NULL,
  `Name` VARCHAR(100),
  `MinValue` INTEGER UNSIGNED,
  `MaxValue` INTEGER UNSIGNED,
  `CalibrationMinValue` FLOAT,
  `ClibrationMaxValue` FLOAT,
  `TriggerValue1` INTEGER UNSIGNED,
  `TriggerValue1Type` INTEGER UNSIGNED,
  `TriggerValue2` INTEGER UNSIGNED,
  `TriggerValue2Type` INTEGER UNSIGNED,
  PRIMARY KEY(`PinNameDBID`),
  CONSTRAINT `FK_PinNames_GPSDevices` FOREIGN KEY `FK_PinNames_GPSDevices` (`DeviceDBID`)
    REFERENCES `gpsdevices` (`DeviceDBID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`GPSRecords` (
  `GPSRecordID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `DeviceDBID` INTEGER UNSIGNED NOT NULL,
  `Latitude` FLOAT NOT NULL,
  `Longitude` FLOAT NOT NULL,
  `East/West` BIt,
  `North/South` BIt,
  `Speed` INTEGER UNSIGNED NOT NULL,
  `Time` DATETIME,
  PRIMARY KEY(`GPSRecordID`),
  CONSTRAINT `FK_GPSRecords_GPSDevices` FOREIGN KEY `FK_GPSRecords_GPSDevices` (`DeviceDBID`)
    REFERENCES `gpsdevices` (`DeviceDBID`)
)
TYPE = InnoDB;


CREATE TABLE `ddb`.`PinData` (
  `PinDBID` INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  `PinNameDBID` INTEGER UNSIGNED NOT NULL,
  `State` INTEGER UNSIGNED NOT NULL,
  `GPSRecordID` INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(`PinDBID`),
  CONSTRAINT `FK_PinData_PinNames` FOREIGN KEY `FK_PinData_PinNames` (`PinNameDBID`)
    REFERENCES `pinnames` (`PinNameDBID`),
  CONSTRAINT `FK_PinData_GPSRecords` FOREIGN KEY `FK_PinData_GPSRecords` (`GPSRecordID`)
    REFERENCES `gpsrecords` (`GPSRecordID`)
)
TYPE = InnoDB;

